@@ -18,7 +18,7 @@ def _get_kwargs(
     *,
     client: AuthenticatedClient,
     json_body: EventExampleIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/endpoint/{endpoint_id}/send-example/".format(
         client.base_url, app_id=app_id, endpoint_id=endpoint_id
@@ -27,7 +27,7 @@ def _get_kwargs(
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body.to_dict()
@@ -72,7 +72,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EventExampleIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Send Event Type Example Message
 
@@ -81,7 +81,7 @@ def sync_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventExampleIn):
 
     Returns:
@@ -121,7 +121,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: EventExampleIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Send Event Type Example Message
 
@@ -130,7 +130,7 @@ def sync(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventExampleIn):
 
     Returns:
@@ -152,7 +152,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EventExampleIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Send Event Type Example Message
 
@@ -161,7 +161,7 @@ async def asyncio_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventExampleIn):
 
     Returns:
@@ -199,7 +199,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: EventExampleIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Send Event Type Example Message
 
@@ -208,7 +208,7 @@ async def asyncio(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         endpoint_id (str): The endpoint's ID or UID Example: ep_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventExampleIn):
 
     Returns:
