@@ -16,14 +16,14 @@ def _get_kwargs(
     integ_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/integration/{integ_id}/".format(client.base_url, app_id=app_id, integ_id=integ_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -62,7 +62,7 @@ def sync_detailed(
     integ_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Get Integration
 
@@ -71,7 +71,7 @@ def sync_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         IntegrationOut
@@ -108,7 +108,7 @@ def sync(
     integ_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Get Integration
 
@@ -117,7 +117,7 @@ def sync(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         IntegrationOut
@@ -136,7 +136,7 @@ async def asyncio_detailed(
     integ_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Get Integration
 
@@ -145,7 +145,7 @@ async def asyncio_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         IntegrationOut
@@ -180,7 +180,7 @@ async def asyncio(
     integ_id: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Get Integration
 
@@ -189,7 +189,7 @@ async def asyncio(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         IntegrationOut
