@@ -18,14 +18,14 @@ def _get_kwargs(
     *,
     client: AuthenticatedClient,
     json_body: IntegrationUpdate,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/integration/{integ_id}/".format(client.base_url, app_id=app_id, integ_id=integ_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body.to_dict()
@@ -68,7 +68,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: IntegrationUpdate,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Update Integration
 
@@ -77,7 +77,7 @@ def sync_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (IntegrationUpdate):
 
     Returns:
@@ -117,7 +117,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: IntegrationUpdate,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Update Integration
 
@@ -126,7 +126,7 @@ def sync(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (IntegrationUpdate):
 
     Returns:
@@ -148,7 +148,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: IntegrationUpdate,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Update Integration
 
@@ -157,7 +157,7 @@ async def asyncio_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (IntegrationUpdate):
 
     Returns:
@@ -195,7 +195,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: IntegrationUpdate,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> IntegrationOut:
     """Update Integration
 
@@ -204,7 +204,7 @@ async def asyncio(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         integ_id (str):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (IntegrationUpdate):
 
     Returns:
