@@ -31,6 +31,12 @@ from .endpoint_out import EndpointOut
 from .endpoint_secret_out import EndpointSecretOut
 from .endpoint_secret_rotate_in import EndpointSecretRotateIn
 from .endpoint_stats import EndpointStats
+from .endpoint_transformation_in import EndpointTransformationIn
+from .endpoint_transformation_out import EndpointTransformationOut
+from .endpoint_transformation_simulate_in import EndpointTransformationSimulateIn
+from .endpoint_transformation_simulate_in_payload import EndpointTransformationSimulateInPayload
+from .endpoint_transformation_simulate_out import EndpointTransformationSimulateOut
+from .endpoint_transformation_simulate_out_payload import EndpointTransformationSimulateOutPayload
 from .endpoint_update import EndpointUpdate
 from .endpoint_updated_event import EndpointUpdatedEvent
 from .endpoint_updated_event_data import EndpointUpdatedEventData
@@ -93,5 +99,6 @@ from .settings_in import SettingsIn
 from .settings_out import SettingsOut
 from .statistics_period import StatisticsPeriod
 from .status_code_class import StatusCodeClass
+from .transformation_http_method import TransformationHttpMethod
 from .validation_error import ValidationError
 from .webhook_types import WebhookTypes
