@@ -24,6 +24,7 @@ class SettingsOut:
         display_name (Union[Unset, None, str]):
         enable_channels (Union[Unset, bool]):
         enable_integration_management (Union[Unset, bool]):
+        enable_transformations (Union[Unset, bool]):
         enforce_https (Union[Unset, bool]):  Default: True.
         event_catalog_published (Union[Unset, None, bool]):
     """
@@ -39,6 +40,7 @@ class SettingsOut:
     display_name: Union[Unset, None, str] = UNSET
     enable_channels: Union[Unset, bool] = False
     enable_integration_management: Union[Unset, bool] = False
+    enable_transformations: Union[Unset, bool] = False
     enforce_https: Union[Unset, bool] = True
     event_catalog_published: Union[Unset, None, bool] = False
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -64,6 +66,7 @@ class SettingsOut:
         display_name = self.display_name
         enable_channels = self.enable_channels
         enable_integration_management = self.enable_integration_management
+        enable_transformations = self.enable_transformations
         enforce_https = self.enforce_https
         event_catalog_published = self.event_catalog_published
 
@@ -92,6 +95,8 @@ class SettingsOut:
             field_dict["enableChannels"] = enable_channels
         if enable_integration_management is not UNSET:
             field_dict["enableIntegrationManagement"] = enable_integration_management
+        if enable_transformations is not UNSET:
+            field_dict["enableTransformations"] = enable_transformations
         if enforce_https is not UNSET:
             field_dict["enforceHttps"] = enforce_https
         if event_catalog_published is not UNSET:
@@ -139,6 +144,8 @@ class SettingsOut:
 
         enable_integration_management = dict_copy.pop("enableIntegrationManagement", UNSET)
 
+        enable_transformations = dict_copy.pop("enableTransformations", UNSET)
+
         enforce_https = dict_copy.pop("enforceHttps", UNSET)
 
         event_catalog_published = dict_copy.pop("eventCatalogPublished", UNSET)
@@ -155,6 +162,7 @@ class SettingsOut:
             display_name=display_name,
             enable_channels=enable_channels,
             enable_integration_management=enable_integration_management,
+            enable_transformations=enable_transformations,
             enforce_https=enforce_https,
             event_catalog_published=event_catalog_published,
         )
